==> zio-aws-iotsitewise_2.12-5.17.102.7-sources.jar: zio/aws/iotsitewise/model/PutStorageConfigurationResponse.scala <==
package zio.aws.iotsitewise.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class PutStorageConfigurationResponse(
    storageType: zio.aws.iotsitewise.model.StorageType,
    multiLayerStorage: Option[zio.aws.iotsitewise.model.MultiLayerStorage] =
      None,
    disassociatedDataStorage: Option[
      zio.aws.iotsitewise.model.DisassociatedDataStorageState
    ] = None,
    retentionPeriod: Option[zio.aws.iotsitewise.model.RetentionPeriod] = None,
    configurationStatus: zio.aws.iotsitewise.model.ConfigurationStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse = {
    import PutStorageConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
      .builder()
      .storageType(storageType.unwrap)
      .optionallyWith(multiLayerStorage.map(value => value.buildAwsValue()))(
        _.multiLayerStorage
      )
      .optionallyWith(disassociatedDataStorage.map(value => value.unwrap))(
        _.disassociatedDataStorage
      )
      .optionallyWith(retentionPeriod.map(value => value.buildAwsValue()))(
        _.retentionPeriod
      )
      .configurationStatus(configurationStatus.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.iotsitewise.model.PutStorageConfigurationResponse.ReadOnly =
    zio.aws.iotsitewise.model.PutStorageConfigurationResponse
      .wrap(buildAwsValue())
}
object PutStorageConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotsitewise.model.PutStorageConfigurationResponse =
      zio.aws.iotsitewise.model.PutStorageConfigurationResponse(
        storageType,
        multiLayerStorage.map(value => value.asEditable),
        disassociatedDataStorage.map(value => value),
        retentionPeriod.map(value => value.asEditable),
        configurationStatus.asEditable
      )
    def storageType: zio.aws.iotsitewise.model.StorageType
    def multiLayerStorage
        : Option[zio.aws.iotsitewise.model.MultiLayerStorage.ReadOnly]
    def disassociatedDataStorage
        : Option[zio.aws.iotsitewise.model.DisassociatedDataStorageState]
    def retentionPeriod
        : Option[zio.aws.iotsitewise.model.RetentionPeriod.ReadOnly]
    def configurationStatus
        : zio.aws.iotsitewise.model.ConfigurationStatus.ReadOnly
    def getStorageType
        : ZIO[Any, Nothing, zio.aws.iotsitewise.model.StorageType] =
      ZIO.succeed(storageType)
    def getMultiLayerStorage: ZIO[
      Any,
      AwsError,
      zio.aws.iotsitewise.model.MultiLayerStorage.ReadOnly
    ] = AwsError.unwrapOptionField("multiLayerStorage", multiLayerStorage)
    def getDisassociatedDataStorage: ZIO[
      Any,
      AwsError,
      zio.aws.iotsitewise.model.DisassociatedDataStorageState
    ] = AwsError.unwrapOptionField(
      "disassociatedDataStorage",
      disassociatedDataStorage
    )
    def getRetentionPeriod: ZIO[
      Any,
      AwsError,
      zio.aws.iotsitewise.model.RetentionPeriod.ReadOnly
    ] = AwsError.unwrapOptionField("retentionPeriod", retentionPeriod)
    def getConfigurationStatus: ZIO[
      Any,
      Nothing,
      zio.aws.iotsitewise.model.ConfigurationStatus.ReadOnly
    ] = ZIO.succeed(configurationStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
  ) extends zio.aws.iotsitewise.model.PutStorageConfigurationResponse.ReadOnly {
    override val storageType: zio.aws.iotsitewise.model.StorageType =
      zio.aws.iotsitewise.model.StorageType.wrap(impl.storageType())
    override val multiLayerStorage
        : Option[zio.aws.iotsitewise.model.MultiLayerStorage.ReadOnly] = scala
      .Option(impl.multiLayerStorage())
      .map(value => zio.aws.iotsitewise.model.MultiLayerStorage.wrap(value))
    override val disassociatedDataStorage
        : Option[zio.aws.iotsitewise.model.DisassociatedDataStorageState] =
      scala
        .Option(impl.disassociatedDataStorage())
        .map(value =>
          zio.aws.iotsitewise.model.DisassociatedDataStorageState.wrap(value)
        )
    override val retentionPeriod
        : Option[zio.aws.iotsitewise.model.RetentionPeriod.ReadOnly] = scala
      .Option(impl.retentionPeriod())
      .map(value => zio.aws.iotsitewise.model.RetentionPeriod.wrap(value))
    override val configurationStatus
        : zio.aws.iotsitewise.model.ConfigurationStatus.ReadOnly =
      zio.aws.iotsitewise.model.ConfigurationStatus
        .wrap(impl.configurationStatus())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
  ): zio.aws.iotsitewise.model.PutStorageConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-iotsitewise_2.12-6.20.56.2-sources.jar: zio/aws/iotsitewise/model/PutStorageConfigurationResponse.scala <==
package zio.aws.iotsitewise.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class PutStorageConfigurationResponse(
    storageType: zio.aws.iotsitewise.model.StorageType,
    multiLayerStorage: Optional[zio.aws.iotsitewise.model.MultiLayerStorage] =
      Optional.Absent,
    disassociatedDataStorage: Optional[
      zio.aws.iotsitewise.model.DisassociatedDataStorageState
    ] = Optional.Absent,
    retentionPeriod: Optional[zio.aws.iotsitewise.model.RetentionPeriod] =
      Optional.Absent,
    configurationStatus: zio.aws.iotsitewise.model.ConfigurationStatus
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse = {
    import PutStorageConfigurationResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
      .builder()
      .storageType(storageType.unwrap)
      .optionallyWith(multiLayerStorage.map(value => value.buildAwsValue()))(
        _.multiLayerStorage
      )
      .optionallyWith(disassociatedDataStorage.map(value => value.unwrap))(
        _.disassociatedDataStorage
      )
      .optionallyWith(retentionPeriod.map(value => value.buildAwsValue()))(
        _.retentionPeriod
      )
      .configurationStatus(configurationStatus.buildAwsValue())
      .build()
  }
  def asReadOnly
      : zio.aws.iotsitewise.model.PutStorageConfigurationResponse.ReadOnly =
    zio.aws.iotsitewise.model.PutStorageConfigurationResponse
      .wrap(buildAwsValue())
}
object PutStorageConfigurationResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotsitewise.model.PutStorageConfigurationResponse =
      zio.aws.iotsitewise.model.PutStorageConfigurationResponse(
        storageType,
        multiLayerStorage.map(value => value.asEditable),
        disassociatedDataStorage.map(value => value),
        retentionPeriod.map(value => value.asEditable),
        configurationStatus.asEditable
      )
    def storageType: zio.aws.iotsitewise.model.StorageType
    def multiLayerStorage
        : Optional[zio.aws.iotsitewise.model.MultiLayerStorage.ReadOnly]
    def disassociatedDataStorage
        : Optional[zio.aws.iotsitewise.model.DisassociatedDataStorageState]
    def retentionPeriod
        : Optional[zio.aws.iotsitewise.model.RetentionPeriod.ReadOnly]
    def configurationStatus
        : zio.aws.iotsitewise.model.ConfigurationStatus.ReadOnly
    def getStorageType
        : ZIO[Any, Nothing, zio.aws.iotsitewise.model.StorageType] =
      ZIO.succeed(storageType)
    def getMultiLayerStorage: ZIO[
      Any,
      AwsError,
      zio.aws.iotsitewise.model.MultiLayerStorage.ReadOnly
    ] = AwsError.unwrapOptionField("multiLayerStorage", multiLayerStorage)
    def getDisassociatedDataStorage: ZIO[
      Any,
      AwsError,
      zio.aws.iotsitewise.model.DisassociatedDataStorageState
    ] = AwsError.unwrapOptionField(
      "disassociatedDataStorage",
      disassociatedDataStorage
    )
    def getRetentionPeriod: ZIO[
      Any,
      AwsError,
      zio.aws.iotsitewise.model.RetentionPeriod.ReadOnly
    ] = AwsError.unwrapOptionField("retentionPeriod", retentionPeriod)
    def getConfigurationStatus: ZIO[
      Any,
      Nothing,
      zio.aws.iotsitewise.model.ConfigurationStatus.ReadOnly
    ] = ZIO.succeed(configurationStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
  ) extends zio.aws.iotsitewise.model.PutStorageConfigurationResponse.ReadOnly {
    override val storageType: zio.aws.iotsitewise.model.StorageType =
      zio.aws.iotsitewise.model.StorageType.wrap(impl.storageType())
    override val multiLayerStorage
        : Optional[zio.aws.iotsitewise.model.MultiLayerStorage.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.multiLayerStorage())
        .map(value => zio.aws.iotsitewise.model.MultiLayerStorage.wrap(value))
    override val disassociatedDataStorage
        : Optional[zio.aws.iotsitewise.model.DisassociatedDataStorageState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.disassociatedDataStorage())
        .map(value =>
          zio.aws.iotsitewise.model.DisassociatedDataStorageState.wrap(value)
        )
    override val retentionPeriod
        : Optional[zio.aws.iotsitewise.model.RetentionPeriod.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.retentionPeriod())
        .map(value => zio.aws.iotsitewise.model.RetentionPeriod.wrap(value))
    override val configurationStatus
        : zio.aws.iotsitewise.model.ConfigurationStatus.ReadOnly =
      zio.aws.iotsitewise.model.ConfigurationStatus
        .wrap(impl.configurationStatus())
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotsitewise.model.PutStorageConfigurationResponse
  ): zio.aws.iotsitewise.model.PutStorageConfigurationResponse.ReadOnly =
    new Wrapper(impl)
}
